==> igniteui-react-layouts-18.1.0.tgz: package/esm5/lib/ToolbarView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { Base, markType, INotifyPropertyChanged_$type, PropertyChangedEventArgs, runOn, delegateCombine, enumGetBox, typeCast, delegateRemove, fromEn } from "igniteui-react-core";
import { RenderingContext } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ToolPanel } from "./ToolPanel";
import { DOMExecutionContext } from "igniteui-react-core";
import { CanvasViewRenderer } from "igniteui-react-core";
import { Size } from "igniteui-react-core";
import { NativeUI } from "igniteui-react-core";
import { FontUtil } from "igniteui-react-core";
import { SRProvider } from "igniteui-react-core";
import { ToolActionCollection } from "./ToolActionCollection";
import { ToolbarOrientation_$type } from "./ToolbarOrientation";
import { ToolbarIconManager } from "./ToolbarIconManager";
import { ToolAction } from "./ToolAction";
import { NativeUIInputsFactory } from "igniteui-react-core";
import { BrushUtil } from "igniteui-react-core";
/**
 * @hidden
 */
var ToolbarView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolbarView, _super);
    function ToolbarView() {
        var _this = _super.call(this) || this;
        _this.n = null;
        _this.m = null;
        _this.a = null;
        _this.i = null;
        _this.l = null;
        _this.e = null;
        _this.k = null;
        _this.b = ((function () {
            var $ret = new FontInfo();
            $ret.n = "Verdana";
            $ret.d = 13;
            $ret.q = "Normal";
            $ret.s = "Normal";
            $ret.o = "Normal";
            return $ret;
        })());
        _this.aa = new Size();
        _this.c = null;
        _this._gridExternal = null;
        _this.f = false;
        _this.j = null;
        return _this;
    }
    ToolbarView.prototype.p = function () {
        return this.i;
    };
    ToolbarView.prototype.v = function () {
    };
    ToolbarView.prototype.t = function (a) {
        if (a == null) {
            this.i = null;
            return;
        }
        this.a.a = new DOMExecutionContext(a);
        this.i = a;
        this.l = this.i.createElement("canvas");
        this.e = new RenderingContext(new CanvasViewRenderer(), this.i.get2DCanvasContext(this.l));
        this.k = this.i.createElement("div");
        this.y();
        var b = new ToolPanel();
        var c = this.i.createElement("div");
        c.setStyleProperty("width", "100%");
        c.setStyleProperty("height", "100%");
        this.i.append(c);
        var d = this.i.getSubRenderer(c);
        b.provideContainer(d);
        var e = this.i.getExternal(b, this.i.rootWrapper, this.i.getExternal(this.a, null, null));
        this.a.am(b);
        var f = Math.round(a.rootWrapper.width());
        var g = Math.round(a.rootWrapper.height());
        this.i.rootWrapper.setStyleProperty("position", "relative");
    };
    ToolbarView.prototype.y = function () {
    };
    ToolbarView.prototype.x = function () {
        if (this.i != null) {
        }
    };
    ToolbarView.prototype.s = function () {
        if (this.i == null) {
            return;
        }
        var a = this.i.rootWrapper.width();
        var b = this.i.rootWrapper.height();
        this.aa = new Size(1, a, b);
    };
    ToolbarView.prototype.z = function () {
        var a = this.i;
        if (null == a) {
            return;
        }
        var b = a.rootWrapper;
        if (null != b) {
            NativeUI.o(b, this.a.a1);
            NativeUI.k(b, this.a.ay);
        }
    };
    ToolbarView.prototype.d = function () {
        return this.b;
    };
    ToolbarView.prototype.u = function () {
    };
    ToolbarView.prototype.w = function () {
    };
    ToolbarView.prototype.r = function () {
    };
    ToolbarView.prototype.g = function () {
        return this.aa.width;
    };
    ToolbarView.prototype.h = function (a) {
        this.c = this.a.p();
        return FontUtil.measureStringWidth(a, this.c, this.e);
    };
    ToolbarView.prototype.q = function (a, b) {
        if (this.j == null) {
            this.j = this.i.createElement("div");
        }
        b(this.j.getNativeElement());
    };
    ToolbarView.$t = markType(ToolbarView, 'ToolbarView');
    return ToolbarView;
}(Base));
export { ToolbarView };
/**
 * @hidden
 */
var Toolbar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Toolbar, _super);
    function Toolbar() {
        var _this = _super.call(this) || this;
        _this.k = null;
        _this.s = false;
        _this.q = null;
        _this.l = null;
        _this.d = new ToolActionCollection();
        _this.b = new ToolActionCollection();
        _this.c = new ToolActionCollection();
        _this.h = Toolbar.i;
        _this.m = null;
        _this.u = Toolbar.v;
        _this.aw = Toolbar.az;
        _this.ax = Toolbar.a0;
        _this.n = null;
        _this.t = false;
        _this.propertyChanged = null;
        _this.a = null;
        ToolbarIconManager.c();
        var a = _this.actions;
        a.collectionChanged = delegateCombine(a.collectionChanged, runOn(_this, _this.ah));
        NativeUIInputsFactory.m();
        var b = new ToolbarView();
        b.a = _this;
        _this.k = b;
        _this.k.v();
        return _this;
    }
    Object.defineProperty(Toolbar.prototype, "r", {
        get: function () {
            if (this.q == null) {
                this.q = new SRProvider(this.k.i);
                this.q.cb("Layouts");
            }
            return this.q;
        },
        enumerable: false,
        configurable: true
    });
    Toolbar.prototype.am = function (a) {
        this.l = a;
        var b = this.l;
        b.onCommand = delegateCombine(b.onCommand, runOn(this, this.ag));
        this.l.k = this.j;
    };
    Toolbar.prototype.ag = function (a, b) {
        if (this.m != null) {
            this.m.onToolCommandExecuting(b.a);
        }
    };
    Toolbar.prototype.ap = function (a) {
    };
    Object.defineProperty(Toolbar.prototype, "autoGeneratedActions", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            var b = this.d;
            this.d = a;
            if (b != this.d) {
                this.aq("AutoGeneratedActions", b, this.d);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "actions", {
        get: function () {
            return this.b;
        },
        set: function (a) {
            var b = this.b;
            this.b = a;
            if (b != this.b) {
                this.aq("Actions", b, this.b);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "actualActions", {
        get: function () {
            return this.c;
        },
        set: function (a) {
            var b = this.c;
            this.c = a;
            if (b != this.c) {
                this.aq("ActualActions", b, this.c);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "j", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            var b = this.h;
            this.h = a;
            if (b != this.h) {
                this.aq("Orientation", enumGetBox(ToolbarOrientation_$type, b), enumGetBox(ToolbarOrientation_$type, a));
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "w", {
        get: function () {
            return this.u;
        },
        set: function (a) {
            var b = this.u;
            this.u = a;
            if (b != this.u) {
                this.aq("Target", b, a);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "ay", {
        get: function () {
            return this.aw;
        },
        set: function (a) {
            var b = this.aw;
            this.aw = a;
            if (b != this.aw) {
                this.aq("BackgroundColor", b, a);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "a1", {
        get: function () {
            return this.ax;
        },
        set: function (a) {
            var b = this.ax;
            this.ax = a;
            if (b != this.ax) {
                this.aq("TextColor", b, a);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "o", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            var b = this.n;
            this.n = a;
            if (b != this.n) {
                this.aq("CellTextStyle", b, this.n);
            }
        },
        enumerable: false,
        configurable: true
    });
    Toolbar.prototype.p = function () {
        if (this.o == null) {
            return this.k.d();
        }
        return this.o;
    };
    Toolbar.prototype.ah = function (a, b) {
        var e_1, _a, e_2, _b;
        if (b.oldItems != null) {
            try {
                for (var _c = __values(fromEn(b.oldItems)), _d = _c.next(); !_d.done; _d = _c.next()) {
                    var c = _d.value;
                    if (typeCast(INotifyPropertyChanged_$type, c) !== null) {
                        var d = c;
                        d.propertyChanged = delegateRemove(d.propertyChanged, runOn(this, this.ai));
                    }
                }
            }
            catch (e_1_1) {
                e_1 = { error: e_1_1 };
            }
            finally {
                try {
                    if (_d && !_d.done && (_a = _c.return))
                        _a.call(_c);
                }
                finally {
                    if (e_1)
                        throw e_1.error;
                }
            }
        }
        if (b.newItems != null) {
            try {
                for (var _e = __values(fromEn(b.newItems)), _f = _e.next(); !_f.done; _f = _e.next()) {
                    var e = _f.value;
                    if (typeCast(INotifyPropertyChanged_$type, e) !== null) {
                        var f = e;
                        f.propertyChanged = delegateCombine(f.propertyChanged, runOn(this, this.ai));
                    }
                }
            }
            catch (e_2_1) {
                e_2 = { error: e_2_1 };
            }
            finally {
                try {
                    if (_f && !_f.done && (_b = _e.return))
                        _b.call(_e);
                }
                finally {
                    if (e_2)
                        throw e_2.error;
                }
            }
        }
        this.ao();
    };
    Toolbar.prototype.ai = function (a, b) {
        this.ao();
    };
    Toolbar.prototype.ao = function () {
        this.au();
    };
    Toolbar.prototype.au = function () {
        if (this.t) {
            return;
        }
        this.t = true;
        this.a.enqueueAction(runOn(this, this.ak));
    };
    Toolbar.prototype.ak = function () {
        if (!this.t) {
            return;
        }
        this.t = false;
        this.av();
        if (this.l.actions != this.actualActions) {
            this.l.actions = this.actualActions;
        }
    };
    Toolbar.prototype.av = function () {
        this.actualActions.clear();
        for (var a = 0; a < this.actions.count; a++) {
            this.actualActions.add(this.actions._inner[a]);
        }
        for (var b = 0; b < this.autoGeneratedActions.count; b++) {
            this.actualActions.add(this.autoGeneratedActions._inner[b]);
        }
    };
    Toolbar.prototype.al = function () {
        if (this.t) {
            this.ak();
        }
    };
    Toolbar.prototype.notifySizeChanged = function () {
        this.k.s();
    };
    Toolbar.prototype.destroy = function () {
        this.provideContainer(null);
    };
    Toolbar.prototype.provideContainer = function (a) {
        this.k.t(a);
    };
    Toolbar.prototype.aq = function (a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.as(a, b, c);
    };
    Toolbar.prototype.as = function (a, b, c) {
        switch (a) {
            case "CellTextStyle":
                this.au();
                break;
            case "BackgroundColor":
            case "TextColor":
                this.au();
                break;
            case "Orientation":
                if (this.l != null) {
                    this.l.k = this.j;
                }
                break;
            case "Target":
                var d = c;
                var e = b;
                this.ar(e, d);
                break;
        }
    };
    Toolbar.prototype.ar = function (a, b) {
        this.m = b;
        if (a != null) {
            this.autoGeneratedActions.clear();
            this.au();
        }
        if (b != null) {
            this.autoGeneratedActions.clear();
            var c = b.getDesiredToolbarActions();
            if (c != null) {
                for (var d = 0; d < c.length; d++) {
                    var e = ToolAction.a(c[d]);
                    this.autoGeneratedActions.add(e);
                }
            }
            this.au();
        }
    };
    Toolbar.$t = markType(Toolbar, 'Toolbar', Base.$, [INotifyPropertyChanged_$type]);
    Toolbar.i = 1;
    Toolbar.v = null;
    Toolbar.az = BrushUtil.g(255, 248, 248, 248);
    Toolbar.a0 = BrushUtil.g(255, 24, 29, 31);
    return Toolbar;
}(Base));
export { Toolbar };

==> igniteui-react-layouts-18.1.3.tgz: package/esm5/lib/ToolbarView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { Base, markType, INotifyPropertyChanged_$type, PropertyChangedEventArgs, runOn, delegateCombine, enumGetBox, typeCast, delegateRemove, fromEn } from "igniteui-react-core";
import { RenderingContext } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ToolPanel } from "./ToolPanel";
import { DOMExecutionContext } from "igniteui-react-core";
import { CanvasViewRenderer } from "igniteui-react-core";
import { Size } from "igniteui-react-core";
import { NativeUI } from "igniteui-react-core";
import { FontUtil } from "igniteui-react-core";
import { SRProvider } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { ToolActionCollection } from "./ToolActionCollection";
import { ToolbarOrientation_$type } from "./ToolbarOrientation";
import { ToolbarIconManager } from "./ToolbarIconManager";
import { ToolAction } from "./ToolAction";
import { NativeUIInputsFactory } from "igniteui-react-core";
import { NativeUIXInputsFactory } from "igniteui-react-inputs";
import { BrushUtil } from "igniteui-react-core";
/**
 * @hidden
 */
var ToolbarView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolbarView, _super);
    function ToolbarView() {
        var _this = _super.call(this) || this;
        _this.n = null;
        _this.m = null;
        _this.a = null;
        _this.i = null;
        _this.l = null;
        _this.e = null;
        _this.k = null;
        _this.b = ((function () {
            var $ret = new FontInfo();
            $ret.n = "Verdana";
            $ret.d = 13;
            $ret.q = "Normal";
            $ret.s = "Normal";
            $ret.o = "Normal";
            return $ret;
        })());
        _this.aa = new Size();
        _this.c = null;
        _this._gridExternal = null;
        _this.f = false;
        _this.j = null;
        return _this;
    }
    ToolbarView.prototype.p = function () {
        return this.i;
    };
    ToolbarView.prototype.v = function () {
    };
    ToolbarView.prototype.t = function (a) {
        if (a == null) {
            this.i = null;
            return;
        }
        this.a.a = new DOMExecutionContext(a);
        this.i = a;
        this.l = this.i.createElement("canvas");
        this.e = new RenderingContext(new CanvasViewRenderer(), this.i.get2DCanvasContext(this.l));
        this.k = this.i.createElement("div");
        this.y();
        var b = new ToolPanel();
        var c = this.i.createElement("div");
        c.setStyleProperty("width", "100%");
        c.setStyleProperty("height", "100%");
        this.i.append(c);
        var d = this.i.getSubRenderer(c);
        b.provideContainer(d);
        var e = this.i.getExternal(b, this.i.rootWrapper, this.i.getExternal(this.a, null, null));
        this.a.aq(b);
        var f = Math.round(a.rootWrapper.width());
        var g = Math.round(a.rootWrapper.height());
        this.i.rootWrapper.setStyleProperty("position", "relative");
    };
    ToolbarView.prototype.y = function () {
    };
    ToolbarView.prototype.x = function () {
        if (this.i != null) {
        }
    };
    ToolbarView.prototype.s = function () {
        if (this.i == null) {
            return;
        }
        var a = this.i.rootWrapper.width();
        var b = this.i.rootWrapper.height();
        this.aa = new Size(1, a, b);
        this.a.at(this.aa);
    };
    ToolbarView.prototype.z = function () {
        var a = this.i;
        if (null == a) {
            return;
        }
        var b = a.rootWrapper;
        if (null != b) {
            NativeUI.o(b, this.a.a6);
            NativeUI.k(b, this.a.a3);
        }
    };
    ToolbarView.prototype.d = function () {
        return this.b;
    };
    ToolbarView.prototype.u = function () {
    };
    ToolbarView.prototype.w = function () {
    };
    ToolbarView.prototype.r = function () {
    };
    ToolbarView.prototype.g = function () {
        return this.aa.width;
    };
    ToolbarView.prototype.h = function (a) {
        this.c = this.a.r();
        return FontUtil.measureStringWidth(a, this.c, this.e);
    };
    ToolbarView.prototype.q = function (a, b) {
        if (this.j == null) {
            this.j = this.i.createElement("div");
        }
        b(this.j.getNativeElement());
    };
    ToolbarView.$t = markType(ToolbarView, 'ToolbarView');
    return ToolbarView;
}(Base));
export { ToolbarView };
/**
 * @hidden
 */
var Toolbar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Toolbar, _super);
    function Toolbar() {
        var _this = _super.call(this) || this;
        _this.k = null;
        _this.u = false;
        _this.s = null;
        _this.l = null;
        _this.m = 0;
        _this.d = new ToolActionCollection();
        _this.b = new ToolActionCollection();
        _this.c = new ToolActionCollection();
        _this.h = Toolbar.i;
        _this.o = null;
        _this.w = Toolbar.x;
        _this.a1 = Toolbar.a4;
        _this.a2 = Toolbar.a5;
        _this.p = null;
        _this.v = false;
        _this.propertyChanged = null;
        _this.a = null;
        ToolbarIconManager.c();
        var a = _this.actions;
        a.collectionChanged = delegateCombine(a.collectionChanged, runOn(_this, _this.ak));
        var b = _this.actualActions;
        b.collectionChanged = delegateCombine(b.collectionChanged, runOn(_this, _this.am));
        NativeUIInputsFactory.n();
        NativeUIXInputsFactory.h();
        var c = new ToolbarView();
        c.a = _this;
        _this.k = c;
        _this.k.v();
        return _this;
    }
    Object.defineProperty(Toolbar.prototype, "t", {
        get: function () {
            if (this.s == null) {
                this.s = new SRProvider(this.k.i);
                this.s.cb("Layouts");
            }
            return this.s;
        },
        enumerable: false,
        configurable: true
    });
    Toolbar.prototype.aq = function (a) {
        this.l = a;
        this.l.n = this.m;
        var b = this.l;
        b.onCommand = delegateCombine(b.onCommand, runOn(this, this.aj));
        this.l.k = this.j;
    };
    Toolbar.prototype.aj = function (a, b) {
        if (this.o != null) {
            this.o.onToolCommandExecuting(b.a);
        }
    };
    Toolbar.prototype.at = function (a) {
        this.l.notifySizeChanged();
    };
    Object.defineProperty(Toolbar.prototype, "n", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            var b = this.m;
            this.m = a;
            if (b != this.m) {
                this.au("BaseTheme", enumGetBox(BaseControlTheme_$type, b), enumGetBox(BaseControlTheme_$type, a));
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "autoGeneratedActions", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            var b = this.d;
            this.d = a;
            if (b != this.d) {
                this.au("AutoGeneratedActions", b, this.d);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "actions", {
        get: function () {
            return this.b;
        },
        set: function (a) {
            var b = this.b;
            this.b = a;
            if (b != this.b) {
                this.au("Actions", b, this.b);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "actualActions", {
        get: function () {
            return this.c;
        },
        set: function (a) {
            var b = this.c;
            this.c = a;
            if (b != this.c) {
                this.au("ActualActions", b, this.c);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "j", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            var b = this.h;
            this.h = a;
            if (b != this.h) {
                this.au("Orientation", enumGetBox(ToolbarOrientation_$type, b), enumGetBox(ToolbarOrientation_$type, a));
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "y", {
        get: function () {
            return this.w;
        },
        set: function (a) {
            var b = this.w;
            this.w = a;
            if (b != this.w) {
                this.au("Target", b, a);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "a3", {
        get: function () {
            return this.a1;
        },
        set: function (a) {
            var b = this.a1;
            this.a1 = a;
            if (b != this.a1) {
                this.au("BackgroundColor", b, a);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "a6", {
        get: function () {
            return this.a2;
        },
        set: function (a) {
            var b = this.a2;
            this.a2 = a;
            if (b != this.a2) {
                this.au("TextColor", b, a);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toolbar.prototype, "q", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            var b = this.p;
            this.p = a;
            if (b != this.p) {
                this.au("CellTextStyle", b, this.p);
            }
        },
        enumerable: false,
        configurable: true
    });
    Toolbar.prototype.r = function () {
        if (this.q == null) {
            return this.k.d();
        }
        return this.q;
    };
    Toolbar.prototype.ak = function (a, b) {
        var e_1, _a, e_2, _b;
        if (b.oldItems != null) {
            try {
                for (var _c = __values(fromEn(b.oldItems)), _d = _c.next(); !_d.done; _d = _c.next()) {
                    var c = _d.value;
                    if (typeCast(INotifyPropertyChanged_$type, c) !== null) {
                        var d = c;
                        d.propertyChanged = delegateRemove(d.propertyChanged, runOn(this, this.al));
                    }
                }
            }
            catch (e_1_1) {
                e_1 = { error: e_1_1 };
            }
            finally {
                try {
                    if (_d && !_d.done && (_a = _c.return))
                        _a.call(_c);
                }
                finally {
                    if (e_1)
                        throw e_1.error;
                }
            }
        }
        if (b.newItems != null) {
            try {
                for (var _e = __values(fromEn(b.newItems)), _f = _e.next(); !_f.done; _f = _e.next()) {
                    var e = _f.value;
                    if (typeCast(INotifyPropertyChanged_$type, e) !== null) {
                        var f = e;
                        f.propertyChanged = delegateCombine(f.propertyChanged, runOn(this, this.al));
                    }
                }
            }
            catch (e_2_1) {
                e_2 = { error: e_2_1 };
            }
            finally {
                try {
                    if (_f && !_f.done && (_b = _e.return))
                        _b.call(_e);
                }
                finally {
                    if (e_2)
                        throw e_2.error;
                }
            }
        }
        this.as();
    };
    Toolbar.prototype.am = function (a, b) {
        this.a0();
    };
    Toolbar.prototype.a0 = function () {
        for (var a = 0; a < this.actualActions.count; a++) {
            this.actualActions._inner[a].g = this.n;
        }
    };
    Toolbar.prototype.al = function (a, b) {
        this.as();
    };
    Toolbar.prototype.as = function () {
        this.ay();
    };
    Toolbar.prototype.ay = function () {
        if (this.v) {
            return;
        }
        this.v = true;
        this.a.enqueueAction(runOn(this, this.ao));
    };
    Toolbar.prototype.ao = function () {
        if (!this.v) {
            return;
        }
        this.v = false;
        this.az();
        if (this.l.actions != this.actualActions) {
            this.l.actions = this.actualActions;
        }
    };
    Toolbar.prototype.az = function () {
        this.actualActions.clear();
        for (var a = 0; a < this.actions.count; a++) {
            this.actualActions.add(this.actions._inner[a]);
        }
        for (var b = 0; b < this.autoGeneratedActions.count; b++) {
            this.actualActions.add(this.autoGeneratedActions._inner[b]);
        }
    };
    Toolbar.prototype.ap = function () {
        if (this.v) {
            this.ao();
        }
    };
    Toolbar.prototype.notifySizeChanged = function () {
        this.k.s();
    };
    Toolbar.prototype.destroy = function () {
        this.provideContainer(null);
    };
    Toolbar.prototype.provideContainer = function (a) {
        this.k.t(a);
    };
    Toolbar.prototype.au = function (a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.aw(a, b, c);
    };
    Toolbar.prototype.aw = function (a, b, c) {
        switch (a) {
            case "CellTextStyle":
                this.ay();
                break;
            case "BackgroundColor":
            case "TextColor":
                this.ay();
                break;
            case "Orientation":
                if (this.l != null) {
                    this.l.k = this.j;
                }
                break;
            case "Target":
                var d = c;
                var e = b;
                this.av(e, d);
                break;
        }
    };
    Toolbar.prototype.av = function (a, b) {
        this.o = b;
        if (a != null) {
            this.autoGeneratedActions.clear();
            this.ay();
        }
        if (b != null) {
            this.autoGeneratedActions.clear();
            var c = b.getDesiredToolbarActions();
            if (c != null) {
                for (var d = 0; d < c.length; d++) {
                    var e = ToolAction.a(c[d]);
                    this.autoGeneratedActions.add(e);
                }
            }
            this.ay();
        }
    };
    Toolbar.$t = markType(Toolbar, 'Toolbar', Base.$, [INotifyPropertyChanged_$type]);
    Toolbar.i = 1;
    Toolbar.x = null;
    Toolbar.a4 = BrushUtil.g(255, 248, 248, 248);
    Toolbar.a5 = BrushUtil.g(255, 24, 29, 31);
    return Toolbar;
}(Base));
export { Toolbar };
